class StreamProtocol:
    rtmp = 'rtmp'
    webrtc = 'webrtc'